diff --git a/doc/src/cursor.rst b/doc/src/cursor.rst
index 73bb537..f3e9aa9 100644
--- a/doc/src/cursor.rst
+++ b/doc/src/cursor.rst
@@ -197,6 +197,30 @@ The ``cursor`` class
         the `~cursor.execute()` method.
 
 
+    .. method:: executequery([buffered=True])
+
+        Execute the next database operation (query or command)
+        submitted to the server with `~cursor.submitqueries()`.
+
+        `buffered` determines whether all query output is collected in
+        a buffer by the client before delivery to the application or
+        whether results are returned to the application as they are
+        received from the server.  (The `cursor.execute()` and
+        `cursor.executemany()` methods always buffer.)
+
+        `!True` is returned if a database operation was executed.
+        `!None` is returned if all submitted database operations have
+        been executed.
+
+        If a query was executed, the returned values can be retrieved
+        using |fetch*|_ methods.
+
+        .. extension::
+
+            The `executequery()` method is a Psycopg extension to
+            the |DBAPI|.
+
+
     .. method:: callproc(procname [, parameters])
             
         Call a stored database procedure with the given name. The sequence of
@@ -230,6 +254,33 @@ The ``cursor`` class
         does nothing but it is safe to call it.
 
 
+    .. method:: submitqueries(operations)
+
+        Submit a string containing one or more database operations
+        (queries or commands) to the database server for execution.
+
+        .. warning::
+
+            Never, **never**, **NEVER** use Python string
+            concatenation (``+``) or string parameters interpolation
+            (``%``) to pass variables to a SQL query string.  See
+            :ref:`query-parameters`.  Always use the
+            `~cursor.mogrify()` method to construct the `operations`
+            string if the SQL contains variable data.
+
+        This function is primarily useful in the context of executing
+        large reports, pre-packaged collections of SQL reports, and
+        arbitrary user-supplied SQL.
+
+        Use the `~cursor.executequery()` method to execute the
+        submitted SQL.
+
+        .. extension::
+
+            The `submitqueries()` method is a Psycopg extension to
+            the |DBAPI|.
+
+
 
     .. |fetch*| replace:: `!fetch*()`
 
